<?php

//Setup -------------
if (! function_exists('bonyo_setup')) :
function bonyo_setup() {

	load_theme_textdomain('bonyo', get_template_directory() . '/languages');

	add_theme_support('post-thumbnails');
	add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
	add_theme_support("title-tag");
	add_theme_support('automatic-feed-links');

	//Content Width
	$GLOBALS['content_width'] = apply_filters('bny_content_width', 624);
}
endif;
add_action('after_setup_theme', 'bonyo_setup');


	
//Load Styles and Scripts -------------
function bny_enq_style_scripts() {

	//style of theme
	wp_enqueue_style('theme-style', get_stylesheet_directory_uri() . '/style.min.css');

	//Font Awesome 4.7.0
	wp_enqueue_style('fontawesome-style', get_stylesheet_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css');

	//Comment Reply
	if (is_singular() && comments_open()) {
		wp_enqueue_script('comment-reply');
	}

	//Disable Style for block editor (Gutenberg)
	wp_dequeue_style('wp-block-library');

}
add_action('wp_enqueue_scripts', 'bny_enq_style_scripts');

//replace style meta tag --------------
function bny_css_async($tag) {
	if (!strpos($tag, 'fontawesome-style') === false) {
		$awesome = get_template_directory_uri() . '/fonts/font-awesome-4.7.0/css/font-awesome.min.css';
		$tag = str_replace('media=\'all\' />', 'media="none" onload="if(media!=\'all\')media=\'all\'"><noscript><link rel="stylesheet" href="' . $awesome . '"></noscript>', $tag);
	}
	return $tag;
}
add_filter('style_loader_tag', 'bny_css_async');




//noindex
function bny_wp_head_noindex() {
	$noidx = '<meta name="robots" content="noindex" />' . "\n";
	if (!is_singular() && !is_front_page() && !is_home()) {
		echo $noidx;
	}
}
add_action('wp_head', 'bny_wp_head_noindex');




//Nav Menu custom class ---------------
class bny_nav_walker extends Walker_Nav_Menu {
	function start_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '<input class="menu-toggle" type="checkbox" /><ul class="sub-menu">';
	}
	function end_lvl(&$output, $depth = 0, $args = array()) {
		$output .= '</ul>';
	}
}



//Sidebar Widget -------------
if (!function_exists('bonyo_widgets_init')):
function bonyo_widgets_init() {
	register_sidebar(array(
		'name'          => esc_html__('Regular Sidebar', 'bonyo'),
		'id'            => 'sidebar-1',
		'description'   => esc_html__('Sidebar for regular pages.', 'bonyo'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
	register_sidebar(array(
		'name'          => esc_html__('Sidebar for AMP pages.', 'bonyo'),
		'id'            => 'sidebar-2',
		'description'   => esc_html__('Register same widgets as for the regular page. However, do not write Javascript in a custom HTML widget for AMP pages.', 'bonyo'),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
}
endif;
add_action('widgets_init', 'bonyo_widgets_init');



//Search widget form ---------------
function bny_search_form($form) {
	$form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
	<div>
		<input type="search" class="search-field" placeholder="" value="' . get_search_query() . '" name="s" />
		<input type="submit" class="search-submit" value="&#xf002;" />
	</div>
	</form>';
	return $form;
}
add_filter('get_search_form', 'bny_search_form');



//Lazy loading (for echo.js)
function bny_lazyloading($content) {

	//AMP
	if(function_exists('is_amp_endpoint') && is_amp_endpoint()) {
		return $content;
	}
	//Admin / Feed
	if (is_admin() or is_feed()) {
		return $content;
	}

	$loaderuri = get_template_directory_uri() . '/images/loader.gif';

	$buf  = '<html><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /></head><body>';
	$buf .= $content;
    $dom = new DOMDocument();
	$dom->formatOutput = false;
	@$dom->loadHTML($buf, LIBXML_HTML_NODEFDTD | LIBXML_NOERROR);

	$images = [];
	foreach ($dom->getElementsByTagName('img') as $node) {  
		$images[] = $node;
	}

	foreach ($images as $node) {
		$fallback = $node->cloneNode(true);

		//src
		$orgsrc = $node->getAttribute('src');
		$node->setAttribute('src', $loaderuri);

		//data-src
		$node->setAttribute('data-echo', $orgsrc );

		//noscript
		$noscript = $dom->createElement('noscript', '');
		$node->parentNode->appendChild($noscript);
		$noscript->appendChild($fallback); 
	}

	$buf = preg_replace('/^\<html\>.*?\<body\>/', '', $dom->saveHTML());
	$buf = preg_replace('/\<\/body\>.*?\<\/html\>\n/', '', $buf);
	return $buf;
}
add_filter('the_content', 'bny_lazyloading');
add_filter('post_thumbnail_html', 'bny_lazyloading');




////Remove Action -------------
remove_action('wp_head', 'wp_generator');	//Hiding "WordPress Version" meta tag.
remove_action('wp_head', 'rsd_link');	//Hiding "RSD(Really Simple Discovery)" meta tag.
remove_action('wp_head', 'wlwmanifest_link');	//Hiding "Windows Live Writer link" meta tag.
remove_action('wp_head', 'rest_output_link_wp_head');	//Hiding "REST API endpoint" 
remove_action('wp_head', 'wp_oembed_add_discovery_links');	//Hiding "oEmbed links"
remove_action('wp_head', 'wp_oembed_add_host_js');	//Hiding "oEmbed JS"
remove_action('wp_head', 'print_emoji_detection_script', 7);	//Hiding Emoji Script
remove_action('wp_print_styles', 'print_emoji_styles');	//Hiding Emoji style



////Disable block editor (Gutenberg Editor) ------------
add_filter('use_block_editor_for_post', '__return_false');

////Disable rich editor ------------
//////add_filter('user_can_richedit', '__return_false');
	


//Extra -------------
//Run css minimizing at logout
function run_at_logout(){
	locate_template('inc/extra-admin.php', true);
	exec_css_minimization();
	if (get_theme_mod('ck_sidebar', false)) {
		bny_static_sidebar(1);        // <- 1 is 'sidebar-1'
	}
	bny_amp_static_sidebar(2);        // <- 2 is 'sidebar-2'
}
add_action('wp_logout', 'run_at_logout');

//Customizer
locate_template('inc/bny-customizer.php', true);

//For Automattic's AMP plugin (classic mode)
locate_template('inc/extra-amp.php', true);

